﻿// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

using System;
using Org.Apache.REEF.Utilities;

namespace Org.Apache.REEF.Common.Tasks
{
    /// <summary>
    /// Task-side TaskMessage.
    /// </summary>
    public class TaskMessage : IMessage
    {
        private readonly string _messageSourceId;
        private readonly byte[] _bytes;

        private TaskMessage(string messageSourceId, byte[] bytes)
        {
            _messageSourceId = messageSourceId;
            _bytes = bytes;
        }

        public string MessageSourceId
        {
            get { return _messageSourceId; }
        }

        public byte[] Message
        {
            get { return _bytes; }
        }

        /// <summary>
        /// From byte[] message to a TaskMessage
        /// </summary>
        /// <param name="messageSourceId">The message's sourceID. This will be accessible in the Driver for routing</param>
        /// <param name="message">The actual content of the message, serialized into a byte[]</param>
        /// <returns>a new TaskMessage with the given content</returns>
        public static TaskMessage From(string messageSourceId, byte[] message)
        {
            if (string.IsNullOrEmpty(messageSourceId))
            {
                throw new ArgumentNullException("messageSourceId");
            }
            if (message == null)
            {
                throw new ArgumentNullException("message");
            }
            return new TaskMessage(messageSourceId, message);
        }
    }
}
